@@ -22,8 +22,8 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-/*
- * Component synchronizing filter storage with Matcher instances and elemhide.
+/**
+ * @fileOverview Component synchronizing filter storage with Matcher instances and elemhide.
  * This file is included from AdblockPlus.js.
  */
 
@@ -134,7 +134,7 @@ var filterListener =
     {
       let method = (action == "add" || action == "enable" ? this.addFilter : this.removeFilter);
       for each (let subscription in subscriptions)
-        if (action == "disable" || !subscription.disabled)
+        if (subscription.filters && (action == "disable" || !subscription.disabled))
           subscription.filters.forEach(method, this);
     }
     else if (action == "update")
