@@ -23,15 +23,21 @@
  * ***** END LICENSE BLOCK ***** */
 
 /**
- * Content policy implementation, responsible for blocking things.
+ * @fileOverview Content policy implementation, responsible for blocking things.
  * This file is included from AdblockPlus.js.
  */
 
 var effectiveTLD = Cc["@mozilla.org/network/effective-tld-service;1"].getService(Ci.nsIEffectiveTLDService);
+var netUtils = Cc["@mozilla.org/network/util;1"].getService(Ci.nsINetUtil);
 
 const ok = Ci.nsIContentPolicy.ACCEPT;
 const block = Ci.nsIContentPolicy.REJECT_REQUEST;
 
+/**
+ * nsIContentPolicy implementation, this gets triggered whenever the browser needs
+ * to load something to decide whether the request should be blocked.
+ * @class
+ */
 var policy =
 {
   /**
@@ -160,7 +166,7 @@ var policy =
     }
 
     // Data loaded by plugins should be attached to the document
-    if ((contentType == this.type.OTHER || contentType == this.type.OBJECT_SUBREQUEST) && node instanceof Element)
+    if (contentType == this.type.OBJECT_SUBREQUEST && node instanceof Element)
       node = node.ownerDocument;
 
     // Fix type for background images
@@ -171,7 +177,7 @@ var policy =
     if (contentType != this.type.OBJECT && (node instanceof Ci.nsIDOMHTMLObjectElement || node instanceof Ci.nsIDOMHTMLEmbedElement))
       contentType = this.type.OBJECT;
 
-    let docDomain = this.getHostname(wnd.location.href);
+    let docDomain = this.getHostname(this.getOriginWindow(wnd).location.href);
     if (!match && contentType == this.type.ELEMHIDE)
     {
       match = location;
@@ -199,9 +205,8 @@ var policy =
           this.schedulePostProcess(node);
       }
 
-      // Show object tabs unless this is a standalone object
-      if (!match && prefs.frameobjects && contentType == this.type.OBJECT &&
-          node.ownerDocument && /^text\/|[+\/]xml$/.test(node.ownerDocument.contentType))
+      // Add object tab
+      if (!match && prefs.frameobjects && contentType == this.type.OBJECT)
       {
         // Before adding object tabs always check whether one exist already
         let hasObjectTab = (node.nextSibling && node.nextSibling.getUserData(this.objtabMarker));
@@ -304,6 +309,23 @@ var policy =
     }
   },
 
+  /**
+   * If the window doesn't have its own security context (e.g. about:blank or
+   * data: URL) walks up the parent chain until a window is found that has a
+   * security context.
+   */
+  getOriginWindow: function(/**Window*/ wnd) /**Window*/
+  {
+    while (wnd != wnd.parent)
+    {
+      let uri = abp.makeURL(wnd.location.href);
+      if (uri.spec != "about:blank" && !netUtils.URIChainHasFlags(uri, Ci.nsIProtocolHandler.URI_INHERITS_SECURITY_CONTEXT))
+        break;
+      wnd = wnd.parent;
+    }
+    return wnd;
+  },
+
   /**
    * Checks whether a page is whitelisted.
    * @param url {String}
@@ -462,6 +484,10 @@ var policy =
     if (!node)
       return ok;
 
+    // Ignore standalone objects
+    if (contentType == this.type.OBJECT && node.ownerDocument && !/^text\/|[+\/]xml$/.test(node.ownerDocument.contentType))
+      return ok;
+
     var wnd = getWindow(node);
     if (!wnd)
       return ok;
