@@ -22,8 +22,8 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-/*
- * Definition of Subscription class and its subclasses.
+/**
+ * @fileOverview Definition of Subscription class and its subclasses.
  * This file is included from AdblockPlus.js.
  */
 
@@ -165,6 +165,8 @@ Subscription.fromObject = function(obj)
         if (abp.versionComparator.compare(result.requiredVersion, abp.getInstalledVersion()) > 0)
           result.upgradeRequired = true;
       }
+      if ("alternativeLocations" in obj)
+        result.alternativeLocations = obj.alternativeLocations;
     }
     if ("lastDownload" in obj)
       result.lastDownload = parseInt(obj.lastDownload) || 0;
@@ -386,6 +388,13 @@ DownloadableSubscription.prototype =
    */
   upgradeRequired: false,
 
+  /**
+   * Value of the X-Alternative-Locations header: comma-separated list of URLs
+   * with their weighting factors, e.g.: http://foo.example.com/;q=0.5,http://bar.example.com/;q=2
+   * @type String
+   */
+  alternativeLocations: null,
+
   /**
    * See Subscription.serialize()
    */
@@ -406,6 +415,8 @@ DownloadableSubscription.prototype =
       buffer.push("errors=" + this.errors);
     if (this.requiredVersion)
       buffer.push("requiredVersion=" + this.requiredVersion);
+    if (this.alternativeLocations)
+      buffer.push("alternativeLocations=" + this.alternativeLocations);
   }
 };
 abp.DownloadableSubscription = DownloadableSubscription;
