@@ -36,7 +36,7 @@ let eventHandlers = [
   ["abp-status-popup", "popupshowing", abpFillPopup],
   ["abp-toolbar-popup", "popupshowing", abpFillPopup],
   ["abp-command-settings", "command", function() { abp.openSettingsDialog(); }],
-  ["abp-command-sidebar", "command", abpToggleSidebar],
+  ["abp-command-sidebar", "command", toggleSidebar],
   ["abp-command-togglesitewhitelist", "command", function() { toggleFilter(siteWhitelist); }],
   ["abp-command-togglepagewhitelist", "command", function() { toggleFilter(pageWhitelist); }],
   ["abp-command-toggleobjtabs", "command", function() { abpTogglePref("frameobjects"); }],
@@ -93,11 +93,17 @@ let progressListener = null;
  */
 let abpHooks = E("abp-hooks");
 
+/**
+ * Window of the detached list of blockable items (might be null or closed).
+ * @type nsIDOMWindow 
+ */
+let detachedSidebar = null;
+
 abpInit();
 
 function abpInit() {
   // Initialize app hooks
-  for each (let hook in ["getBrowser", "addTab", "getContextMenu", "getToolbox", "getDefaultToolbar", "toolbarInsertBefore"])
+  for each (let hook in ["init", "getBrowser", "addTab", "getContextMenu", "getToolbox", "getDefaultToolbar", "toolbarInsertBefore"])
   {
     let handler = abpHooks.getAttribute(hook);
     if (handler)
@@ -105,7 +111,6 @@ function abpInit() {
   }
 
   // Process preferences
-  window.abpDetachedSidebar = null;
   abpReloadPrefs();
 
   // Copy the menu from status bar icon to the toolbar
@@ -211,8 +216,8 @@ function abpInit() {
     prefs.doneFirstRunActions = true;
 
     // Show subscriptions dialog if the user doesn't have any subscriptions yet
-    if (abp.versionComparator.compare(prefs.lastVersion, "0.0") <= 0)
-      abp.runAsync(abpShowSubscriptions);
+    if (prefs.lastVersion != prefs.currentVersion)
+      abp.runAsync(showSubscriptions);
   }
 
   // Window-specific first run actions
@@ -240,6 +245,9 @@ function abpInit() {
         abp.runAsync(abpInstallInToolbar);
     }
   }
+
+  if ("init" in abpHooks)
+    abpHooks.init();
 }
 
 function abpUnload()
@@ -292,11 +300,13 @@ function abpReloadPrefs() {
 
   var status = E("abp-status");
   updateElement(status);
-  if (prefs.defaultstatusbaraction == 0)
-    status.setAttribute("popup", status.getAttribute("context"));
-  else
-    status.removeAttribute("popup");
-
+  if (status) {
+    if (prefs.defaultstatusbaraction == 0)
+      status.setAttribute("popup", status.getAttribute("context"));
+    else
+      status.removeAttribute("popup");
+  }
+  
   var button = E("abp-toolbarbutton");
   updateElement(button);
   if (button) {
@@ -318,9 +328,6 @@ function abpReloadPrefs() {
  */
 function shouldHideImageManager()
 {
-  if (typeof arguments.callee._result != "undefined")
-    return arguments.callee._result;
-
   let result = false;
   if (prefs.hideimagemanager && "@mozilla.org/permissionmanager;1" in Cc)
   {
@@ -344,7 +351,7 @@ function shouldHideImageManager()
     }
   }
 
-  arguments.callee._result = result;
+  shouldHideImageManager = function() result;
   return result;
 }
 
@@ -398,39 +405,61 @@ function handleLinkClick(/**Event*/ event)
   if (event.button == 2)
     return;
 
+  // Search the link associated with the click
   let link = event.target;
   while (link && !(link instanceof Ci.nsIDOMNSHTMLAnchorElement))
     link = link.parentNode;
 
-  if (link && /^abp:\/*subscribe\/*\?(.*)/i.test(link.href))
+  if (!link || !/^abp:\/*subscribe\/*\?(.*)/i.test(link.href))
+    return;
+
+  // This is our link - make sure the browser doesn't handle it
+  event.preventDefault();
+  event.stopPropagation();
+
+  // Decode URL parameters
+  let title = null;
+  let url = null;
+  for each (let param in RegExp.$1.split('&'))
   {
-    event.preventDefault();
-    event.stopPropagation();
+    let parts = param.split("=", 2);
+    if (parts.length == 2 && parts[0] == 'title')
+      title = decodeURIComponent(parts[1]);
+    if (parts.length == 2 && parts[0] == 'location')
+      url = decodeURIComponent(parts[1]);
+  }
+  if (!url || !/\S/.test(url))
+    return;
 
-    let unescape = Cc["@mozilla.org/intl/texttosuburi;1"].getService(Ci.nsITextToSubURI);
+  // Default title to the URL
+  if (!title || !/\S/.test(title))
+    title = url;
 
-    let params = RegExp.$1.split('&');
-    let title = null;
-    let url = null;
-    for each (let param in params)
-    {
-      let parts = param.split("=", 2);
-      if (parts.length == 2 && parts[0] == 'title')
-        title = decodeURIComponent(parts[1]);
-      if (parts.length == 2 && parts[0] == 'location')
-        url = decodeURIComponent(parts[1]);
-    }
+  // Trim spaces in title and URL
+  title = title.replace(/^\s+/, "").replace(/\s+$/, "");
+  url = url.replace(/^\s+/, "").replace(/\s+$/, "");
 
-    if (url && /\S/.test(url))
-    {
-      if (!title || !/\S/.test(title))
-        title = url;
+  // Verify that the URL is valid
+  url = abp.makeURL(url);
+  if (!url)
+    return;
+  if (url.scheme != "http" && url.scheme != "https" && url.scheme != "ftp")
+    return;
+  url = url.spec;
 
-      var subscription = {url: url, title: title, disabled: false, external: false, autoDownload: true};
-
-      window.openDialog("chrome://adblockplus/content/ui/subscription.xul", "_blank",
-                         "chrome,centerscreen,modal", subscription);
-    }
+  // Open dialog
+  let appInfo = Cc["@mozilla.org/xre/app-info;1"].getService(Ci.nsIXULAppInfo);
+  if (appInfo.ID != "{a23983c0-fd0e-11dc-95ff-0800200c9a66}")
+  {
+    var subscription = {url: url, title: title, disabled: false, external: false, autoDownload: true};
+    window.openDialog("chrome://adblockplus/content/ui/subscription.xul", "_blank",
+                     "chrome,centerscreen,modal", subscription);
+  }
+  else
+  {
+    // Special handling for Fennec
+    window.importDialog(null, "chrome://adblockplus/content/ui/fennecSubscription.xul");
+    initFennecSubscriptionDialog(url, title);
   }
 }
 
@@ -469,13 +498,24 @@ function abpInstallInToolbar()
   }
 }
 
-// Let user choose subscriptions on first start unless he has some already
-function abpShowSubscriptions()
+/**
+ * Executed on first run, presents the user with a list of filter subscriptions
+ * and allows choosing one.
+ */
+function showSubscriptions()
 {
-  // Look for existing subscriptions
-  for each (let subscription in filterStorage.subscriptions)
-    if (subscription instanceof abp.DownloadableSubscription)
-      return;
+  // In Fennec we might not be initialized yet
+  abp.init();
+
+  // Don't annoy the user if he has a subscription already
+  let hasSubscriptions = filterStorage.subscriptions.some(function(subscription) subscription instanceof abp.DownloadableSubscription);
+  if (hasSubscriptions)
+    return;
+
+  // Only show the list if this is the first run or the user has no filters
+  let hasFilters = filterStorage.subscriptions.some(function(subscription) subscription.filters.length);
+  if (hasFilters && abp.versionComparator.compare(prefs.lastVersion, "0.0") > 0)
+    return;
 
   if (!abpHooks.addTab || abpHooks.addTab("chrome://adblockplus/content/ui/tip_subscriptions.xul") === false)
     window.openDialog("chrome://adblockplus/content/ui/tip_subscriptions.xul", "_blank", "chrome,centerscreen,resizable,dialog=no");
@@ -666,19 +706,25 @@ function abpFillPopup(event) {
 
 function abpIsSidebarOpen() {
   // Test whether detached sidebar window is open
-  if (window.abpDetachedSidebar && !window.abpDetachedSidebar.closed)
+  if (detachedSidebar && !detachedSidebar.closed)
     return true;
 
   var sidebar = E("abp-sidebar");
   return (sidebar ? !sidebar.hidden : false);
 }
 
-function abpToggleSidebar() {
-  if (window.abpDetachedSidebar && !window.abpDetachedSidebar.closed)
-    window.abpDetachedSidebar.close();
-  else {
+function toggleSidebar()
+{
+  if (detachedSidebar && !detachedSidebar.closed)
+  {
+    detachedSidebar.close();
+    detachedSidebar = null;
+  }
+  else
+  {
     var sidebar = E("abp-sidebar");
-    if (sidebar && (!prefs.detachsidebar || !sidebar.hidden)) {
+    if (sidebar && (!prefs.detachsidebar || !sidebar.hidden))
+    {
       E("abp-sidebar-splitter").hidden = !sidebar.hidden;
       E("abp-sidebar-browser").setAttribute("src", sidebar.hidden ? "chrome://adblockplus/content/ui/sidebar.xul" : "about:blank");
       sidebar.hidden = !sidebar.hidden;
@@ -686,7 +732,7 @@ function abpToggleSidebar() {
         abpHooks.getBrowser().contentWindow.focus();
     }
     else
-      window.abpDetachedSidebar = window.openDialog("chrome://adblockplus/content/ui/sidebarDetached.xul", "_blank", "chrome,resizable,dependent,dialog=no,width=600,height=300");
+      detachedSidebar = window.openDialog("chrome://adblockplus/content/ui/sidebarDetached.xul", "_blank", "chrome,resizable,dependent,dialog=no");
   }
 
   let menuItem = E("abp-blockableitems");
@@ -751,7 +797,7 @@ function abpCommandHandler(e) {
 // Executes default action for statusbar/toolbar by its number
 function abpExecuteAction(action) {
   if (action == 1)
-    abpToggleSidebar();
+    toggleSidebar();
   else if (action == 2)
     abp.openSettingsDialog();
   else if (action == 3)
