@@ -7,7 +7,7 @@
 
 use strict;
 use warnings;
-use lib qw(..);
+use lib qw(buildtools);
 use Packager;
 
 sub Packager::fixLocales() {}
@@ -32,7 +32,7 @@ chdir('chrome');
 $pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete');
 chdir('..');
 
-my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest');
+my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
 
 my $targetAppNum = 0;
 $pkg->{postprocess_line} = \&postprocessInstallRDF;
